@@ -39,7 +39,7 @@ setMethod(".gbutton",
             if (!is.null(container)) {
               if(is.logical(container) && container == TRUE)
                 container = gwindow(visible=TRUE)
-              add(container, obj)
+              add(container, obj, ...)
             }
 
             ## add handler
